Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions.
Este commit está contenido en:
@@ -34,7 +34,7 @@ THE SOFTWARE.
|
||||
#define kernel_name "hello_world"
|
||||
|
||||
__global__ void Cpy(hipLaunchParm lp, float *Ad, float* Bd){
|
||||
int tx = threadIdx.x;
|
||||
int tx = hipThreadIdx_x;
|
||||
Bd[tx] = Ad[tx];
|
||||
}
|
||||
|
||||
|
||||
Referencia en una nueva incidencia
Block a user